* PART I. ANALYSIS USING AMERICAN NATIONAL ELECTIONS STUDY 2000 DATASET


* STEP 0. DOWNLOAD ANES 2000 PREPOST DATASET AND UNPACK IT INTO STATA DTA FORMAT
* WEBSITE ADDRESS: http://www.electionstudies.org/studypages/2000prepost/2000prepost.htm


* STEP 1. CREATION OF DEPENDENT VARIABLES

* POLITICAL INTEREST AND PARTICIPATION VARIABLES

recode V001648 (8 9 0=.) (5=0) (4=1) (3=2) (2=3) (1=4), gen(attnprescamps)
label var attnprescamps "Attention paid to these presidential campaign news"

recode V001649 (8 9 0=.) (5=0) (4=1) (3=2) (2=3) (1=4), gen(attncongcamps)
label var attncongcamps "Attention paid to these Congressional campaign news"

recode V001367 (4=0) (3=1) (2=2) (1=3) (0 8 9=.), gen(flwgovt)
label var flwgovt "Follow gov't and public affairs"

recode V001241 (4=1) (1 2 3=0) (0 8=.), gen(turnout)
label var turnout "Voted in 2000 elections"

* POLITICAL KNOWLEDGE VARIABLES

* Creation of legislative party control knowledge score: 0 if wrong answer for both chambers, 1 if correct answer for one chamber (only), 2 if correct answer for both chambers
recode V001356 (0=.) (1 8=0) (5=1), gen(pctrlH)
recode V001357 (0=.) (1 8=0) (5=1), gen(pctrlS)
gen partyctrl=pctrlH+pctrlS
label var partyctrl "Party control knowledge score"

*Creation of public figure recognition score: 1 point for each of the 4 figures correctly identified
gen pubfig1=.
replace pubfig1=0 if V001447==5
replace pubfig1=0 if V001447==8
replace pubfig1=1 if V001447==1
gen pubfig2=.
replace pubfig2=0 if V001450==5
replace pubfig2=0 if V001450==8
replace pubfig2=1 if V001450==1
gen pubfig3=.
replace pubfig3=0 if V001453==5
replace pubfig3=0 if V001453==8
replace pubfig3=1 if V001453==1
gen pubfig4=.
replace pubfig4=0 if V001456==5
replace pubfig4=0 if V001456==8
replace pubfig4=1 if V001456==1
gen pubfigrecog=pubfig1+pubfig2+pubfig3+pubfig4
label var pubfigrecog "Public figure recognition score"

*Creation of presidential and vice-pres candidate knowledge scores
recode V001458 (0 9=.) (1 2 4 7 8=0) (3=1), gen(busha)
recode V001460 (9=.) (0 1 3 7 8=0) (2=1), gen(bushr)
recode V001462 (0 9=.) (1 3 4 7 8=0) (2=1), gen(gorea)
recode V001464 (9=.) (0 2 3 7 8=0) (1=1), gen(gorer)
recode V001466 (0 9=.) (1 2 3 7 8=0) (4=1), gen(cheneya)
recode V001468 (9=.) (0 1 3 7 8=0) (2=1), gen(cheneyr)
recode V001470 (0 9=.) (2 3 4 7 8=0) (1=1), gen(liebermana)
recode V001472 (9=.) (0 1 2 7 8=0) (3=1), gen(liebermanr)
gen pvpscore=busha+bushr+gorea+gorer+cheneya+cheneya+liebermana+liebermanr
label var pvpscore "Presid and VP knowledge score"

*Creation of interviewer's evaluation of R's political knowledge
recode V001745 (0=.) (5=0) (4=1) (3=2) (2=3) (1=4), gen(evalscore)
label var evalscore "Interviewer's evaluation of respondent's political knowledge"

* POLITICAL EFFICACY VARIABLES

recode V001516 (0 8 9=.) (5=0) (4=1) (3=2) (2=3) (1=4), gen(goodundrstpol)
label var goodundrstpol "Feel to have good underst of politics"

recode V001520 (0 8 9=.) (5=0) (4=1) (3=2) (2=3) (1=4), gen(votematters)
label var votematters "Feel that my vote matters"

recode V001527 (0 8 9=.) (1=0) (2=1) (3=2) (4=3) (5=4), gen(publofcare)
label var publofcare "Feel that public officials care what people think"

recode V001528 (0 8 9=.) (1=0) (2=1) (3=2) (4=3) (5=4), gen(havesay)
label var havesay "Feel that people have say about what govt does"

* POLITICAL INFORMATION ACQUSITION/SEEKING VARIABLES

*Creation of presidential TV debate watching variable
gen tvdeb=.
replace tvdeb=0 if V001644==5
replace tvdeb=1 if V001645==5
replace tvdeb=2 if V001645==1
label var tvdeb "Intensity of watching presidential TV debates"

*Creation of variable for listening to radio programs about the campaign: 0 none, 1 one-two, 2 several 3 many
gen radiocamp=.
replace radiocamp=0 if V001646==5
replace radiocamp=1 if V001647==5
replace radiocamp=2 if V001647==3
replace radiocamp=3 if V001647==1
label var radiocamp "Intensity of listening to radio programs about the campaign"

*Creation of variable for seeing Internet info about the campaign
gen netcamp=.
replace netcamp=0 if  V001434==5
replace netcamp=1 if  V001434==1
label var netcamp "Has seen information on Internet about the campaign"


* STEP 2. CREATION OF MAIN EXPLANATORY VARIABLES

*Creation of variable for political discussion network size
recode V001699 (0=.) (5=0) (1=1), gen(pnet1)
recode V001700 (9=.) (0 5=0) (1=1), gen(pnet2)
recode V001701 (0 5=0) (1=1), gen(pnet3)
recode V001702 (0 5=0) (1=1), gen(pnet4)
gen pnet=pnet1+pnet2+pnet3+pnet4
label var pnet "Size of political discussion network"

gen pnetQ=pnet*pnet
label var pnetQ "Size of political discussion network, squared"

tab pnet, gen(pnetD)
label var pnetD1 "No one with whom disc. politics"
label var pnetD2 "Discuss politics with 1 person"
label var pnetD3 "Discuss politics with 2 people"
label var pnetD4 "Discuss politics with 3 people"
label var pnetD5 "Discuss politics with 4 people"


* STEP 3. CREATION OF CONTROLS

*Socio-demographic characteristics

gen age=V000908
replace age=. if V000908==00
label var age "Age"

gen ageQ= age*age
label var ageQ "Age, squared"

recode V001029 (1=0) (2=1), gen(gender)
label var gender "Gender = female"

recode V000909 (0 8 9=.) (2 3 4 5=0) (1 6=1), gen(ms)
label var ms "Marital status"

recode V001006a (00 90 98 99=.) (50=0) (10=1) (40=2) (20 30 60 75 76 79 80=3), gen(race)
tab race, gen(rc)
label var rc1 "Race = White"
label var rc2 "Race = African-American"
label var rc3 "Race = Latino"
label var rc4 "Race = Other"

recode V000994 (00 98 99=.), gen (HHinc)
label var HHinc "Household income (category)"

recode V001022 (0 9=.) (5 7=0) (1=1), gen(homeown)
label var homeown "Homeownership"

recode V000913 (9=.) (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) , gen(edu)
label var edu "Education (category)"

recode V001020c (96 97=.), gen(residy)
replace residy=age if V001020c==96
label var residy "Length of residence in community, years"

*Individual social characteristics

recode V000879 (0 8 9=.) (5=0) (4=1) (3=2) (2=3) (1=4), gen(religattend)
replace religattend=0 if V000877==5
label var religattend "Attend religious services (frequency)"

recode V001419 (0 8 9=.) (5=0) (1=1), gen(jury)
label var jury "Would serve on jury duty"

recode V001475 (0 8 9=.) (5=0) (1=1), gen(trust)
label var trust "Trust in other people"

recode V001494 (0=.) (5=0) (1=1), gen(memberorg)
label var memberorg "Member of an organization"

*Past voting

recode V000303 (8 9=.) (5=0) (1=1), gen(voted96)
label var voted96 "Turnout in 1996 Pres. elections"

*State controls

recode V000080 (96 99=.), gen(st)
label var st "State code"
tab st, gen(state)


* STEP 4. SUMMARY STATISTICS AND FIGURES

*Summary statistics for political discussion/social network variables
sum pnet pnetD1 pnetD2 pnetD3 pnetD4 pnetD5

*Summary statistics for political interest and participation variables
sum attnprescamps attncongcamps flwgovt turnout 

*Summary statistics for political knowledge variables
sum partyctrl pubfigrecog pvpscore evalscore
 
*Summary statistics for political efficacy variables 
sum goodundrstpol votematters publofcare havesay

*Summary statistics for political information acquisition/seeking variables
sum tvdeb radiocamp netcamp 

*Figure 1
graph bar (mean) tvdeb pubfigrecog attnpres , over(pnet) bar(1,bfcolor(gs0)) bar(2,bfcolor(gs8)) bar(3,bfcolor(16)) legend(label(1 "Intensity of watching TV debates") label(2 "Public figure recogn.") label(3 "Attention to Presidential campaign news")) title("Fig. 1. Average political information acquisition - ANES 2000") subtitle("by size of social network")


* STEP 5. REGRESSION ANALYSIS

*Ordered probit regressions with political information acquisition/seeking as dependent variables

oprobit tvdeb pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st)table
outreg using c:\anes\acquis.doc, title (Network size and political information acquisition) se noaster nonotes

oprobit radiocamp pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st)table
outreg using c:\anes\acquis.doc, append se noaster nonotes

dprobit netcamp pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st)
* NB: binary dependent variable, thus probit is used
outreg using c:\anes\acquis.doc, append se noaster nonotes


*Ordered probit regressions with political interest and participation as dependent variables

oprobit attnprescamps pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\polint.doc, title (Network size and political interest/participation) se noaster nonotes

oprobit  attncongcamps pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\polint.doc, append se noaster nonotes

oprobit flwgovt pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\polint.doc, append se noaster nonotes

dprobit turnout pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st)
* NB: binary dependent variable, thus probit is used
outreg using c:\anes\polint.doc, append se noaster nonotes


*Ordered probit regressions with political knowledge as dependent variables

oprobit partyctrl pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\polknow.doc, title (Network size and political knowledge) se noaster nonotes

oprobit  pubfigrecog pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\polknow.doc, append se noaster nonotes

oprobit pvpscore pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\polknow.doc, append se noaster nonotes

oprobit evalscore pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\polknow.doc, append se noaster nonotes

reg pvpscore pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st)
*NB: OLS is used
outreg using c:\anes\polknow.doc, append se noaster nonotes


*Ordered probit regressions with self-reported political efficacy measures as dependent variables

oprobit goodundrstpol pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\self.doc, title (Network size and political efficacy) se noaster nonotes

oprobit  votematters pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\self.doc, append se noaster nonotes

oprobit publofcare pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\self.doc, append se noaster nonotes

oprobit havesay pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\self.doc, append se noaster nonotes


*Robustness analysis

*Inclusion of state fixed effects

oprobit attnprescamps pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96  state1-state49, cluster(st) table
outreg using c:\anes\robust.doc, title (Robustness analysis) se noaster nonotes

oprobit pvpscore pnetD1-pnetD4 age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96  state1-state49, cluster(st) table
outreg using c:\anes\robust.doc, append se noaster nonotes

*Use of linear-quadratic specification (instead of dummies for network size)

oprobit tvdeb pnet pnetQ age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\robust.doc, append se noaster nonotes

oprobit attnprescamps pnet pnetQ age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\robust.doc, append se noaster nonotes

oprobit pvpscore pnet pnetQ age ageQ gender ms rc2- rc4 HHinc homeown edu residy religattend jury trust memberorg voted96 , cluster(st) table
outreg using c:\anes\robust.doc, append se noaster nonotes



* PART II. ANALYSIS USING EUROPEAN SOCIAL SURVEYS 2002-2006 CUMULATIVE DATASET


* STEP 0. DOWNLOAD ESS 2002-2006 CUMULATIVE DATASET AND CONVERT IT INTO STATA DTA FORMAT
* WEBSITE ADDRESS: http://ess.nsd.uib.no/ess/cumulative/


* STEP 1. CREATION OF DEPENDENT VARIABLES

* POLITICAL INFORMATION ACQUSITION/SEEKING VARIABLES

*Variables tvpol, rdpol, and nwsppol do not need recoding


* POLITICAL INTEREST AND PARTICIPATION VARIABLES

recode vote (3=.) (2=0) (1=1), gen(turnout)
label var turnout "Voted in the last national elections"

recode polintr (4=0) (3=1) (2=2) (1=3), gen (interestpol)
label var interestpol "How much interested in politics"


* POLITICAL EFFICACY VARIABLES

recode polcmpl (5=0) (4=1) (3=2) (2=3) (1=4), gen(disagpolcompl)
label var disagpolcompl "Disagree that politics is too complicated to understand"

*Variables poldcs, trstprl, trstplt, trstep, stfdem do not need recoding

 
* STEP 2. CREATION OF MAIN EXPLANATORY VARIABLES

gen sclmeet1=sclmeet-1
label var sclmeet1 "Frequency of socialization"

gen sclmeetQ=sclmeet*sclmeet
label var sclmeetQ "Frequency of socialization, squared"

tab sclmeet1, gen(sclmt)
label var sclmt1 "Freq. of socialization = none"
label var sclmt2 "Freq. of socialization = less than once a month"
label var sclmt3 "Freq. of socialization = once a month"
label var sclmt4 "Freq. of socialization = several times a month"
label var sclmt5 "Freq. of socialization = once a week"
label var sclmt6 "Freq. of socialization = several times a week"
label var sclmt7 "Freq. of socialization = every day"

gen sclact1=sclact-1
label var sclact1 "Taking part in social activities as compared to others of same age"

gen sclactQ=sclact*sclact
label var sclactQ "Taking part in social activities (relative), squared"

tab sclact1, gen(scla)
label var scla1 "Taking part in social activities = much less than most"
label var scla2 "Taking part in social activities = less than most"
label var scla3 "Taking part in social activities = about the same"
label var scla4 "Taking part in social activities = more than most"
label var scla5 "Taking part in social activities = much more than most"


* STEP 3. CREATION OF CONTROLS

*Socio-demographic characteristics

gen age=inwyr-yrbrn
label var age "Age"

gen ageQ= age*age
label var ageQ "Age, squared"

recode gndr (1=0) (2=1), gen(gender)
label var gender "Gender = female"

recode marital (2 3 4 5=0) (1=1), gen(ms)
label var ms "Marital status"

tab hinctnt, gen(income)

*Variable eduyrs does not need recoding

tab domicil, gen(dom)
label var dom1 "Place of residence = big city"
label var dom2 "Place of residence = suburb"
label var dom3 "Place of residence = town"
label var dom4 "Place of residence = village"
label var dom5 "Place of residence = countryside"

*Individual social characteristics

*Variable ppltrst do not need recoding

recode wrkorg (2=0), gen(memberorg)
label var memberorg "Has worked in a non-political organization last yr"

recode rlgatnd (7=0) (6=1) (5=2) (4=3) (3=4) (2=5) (1=6), gen(relig)
label var relig "Attend religious services (frequency)"

*Country countrols

tab cntry, gen (cntry)


* STEP 4. SUMMARY STATISTICS

*Summary statistics for social network variables
sum sclmeet1 sclmt1-sclmt7 sclact1 scla1-scla5

*Summary statistics for political information acquisition/seeking variables
sum tvpol rdpol nwsppol

*Summary statistics for political interest and participation variables
sum turnout interestpol

*Summary statistics for political efficacy variables 
sum disagpolcompl poldcs trstprl trstplt trstep stfdem 

*Figure 2
graph bar (mean) nwsppol interestpol disagpol, over(sclmeet1) bar(1,bfcolor(gs0)) bar(2,bfcolor(gs8)) bar(3,bfcolor(16)) legend(label(1 "Reading politics in newspapers") label(2 "Interest in politics") label(3 "Disagree that politics is too complicated to understand")) title("Fig. 2. Average pol. info. acquisition - ESS 2002-2006") subtitle("by frequency of socialization")


* STEP 5. REGRESSION ANALYSIS

*Ordered probit regressions with political information acquisition/seeking as dependent variables

oprobit tvpol sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\acquis.doc, title (ESS - Network size and political information acquisition/seeking) se noaster nonotes

oprobit rdpol sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\acquis.doc, append se noaster nonotes

oprobit nwsppol sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\acquis.doc, append se noaster nonotes


*Ordered probit regressions with political interest and participation as dependent variables
oprobit interestpol sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\polint.doc, title (ESS - Network size and political interest/participation) se noaster nonotes

dprobit turnout sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\polint.doc, append se noaster nonotes

*Ordered probit regressions with self-reported political efficacy measures as dependent variables
oprobit disagpolcompl sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\self.doc, title (ESS - Network size and political efficacy) se noaster nonotes

oprobit poldcs sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\self.doc, append se noaster nonotes

oprobit trstprl sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\self.doc, append se noaster nonotes

oprobit trstplt sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\self.doc, append se noaster nonotes

oprobit trstep sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\self.doc, append se noaster nonotes

oprobit stfdem sclmt1-sclmt6 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\self.doc, append se noaster nonotes


*Robustness analysis

*Use of linear-quadratic specification (instead of dummies for network size)
oprobit tvpol sclmeet1 sclmeetQ age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\robust.doc, title (ESS - Robustness analysis) se noaster nonotes

*Use of relative taking part in social activities (instead of absolute frequency of socialization)
oprobit tvpol scla1-scla4 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\robust.doc, append se noaster nonotes

oprobit interestpol scla1-scla4 age ageQ gender ms eduyrs income1-income12 dom2-dom5 ppltrst memberorg relig cntry1 - cntry24
outreg using c:\ess\robust.doc, append se noaster nonotes


*END
